hdefs["ENABLE_NLS"] = nil
hdefs["PREFIX"] = "/usr/local"
hdefs["BINDIR"] = "/usr/local/bin"
hdefs["LIBDIR"] = "/usr/local/lib"
hdefs["MODULEDIR"] = "/usr/local/lib"
hdefs["LIBEXECDIR"] = "/usr/local/libexec"
hdefs["DATADIR"] = "/usr/local/share"
hdefs["STATEDIR"] = "/usr/local/var"
hdefs["SYSCONFDIR"] = "/usr/local/etc"
hdefs["LOCALEDIR"] = "/usr/local/share/locale"
hdefs["MANDIR"] = "/usr/local/man"
hdefs["PACKAGE"] = "Agar"
hdefs["VERSION"] = "1.7.0"
hdefs["RELEASE"] = "Ancient Egypt"
hdefs["DATADIR"] = "/usr/local/share/agar"
hdefs["LOCALEDIR"] = "/usr/local/share/agar/locale"
hdefs["TTFDIR"] = "/usr/local/share/agar/fonts"
hdefs["INCLDIR"] = "/usr/local/include/agar"
hdefs["AG_MODEL"] = AG_MEDIUM
hdefs["HAVE_EMCC"] = "no"
hdefs["HAVE_CC65"] = "no"
hdefs["EXECSUFFIX"] = ""
hdefs["HAVE_CC_CLANG"] = "yes"
hdefs["HAVE_CC65"] = nil
hdefs["HAVE_EMCC"] = nil
hdefs["HAVE_CC_GCC"] = nil
hdefs["HAVE_CC_WARNINGS"] = "yes"
hdefs["HAVE_FLOAT"] = "yes"
hdefs["HAVE_LONG_DOUBLE"] = "yes"
hdefs["HAVE_LONG_LONG"] = "yes"
hdefs["HAVE_CYGWIN"] = nil
hdefs["HAVE_CC"] = "yes"
hdefs["EXECSUFFIX"] = ""
hdefs["HAVE_OBJC_WARNINGS"] = "yes"
hdefs["HAVE_OBJC"] = "yes"
hdefs["_MK_LITTLE_ENDIAN"] = "yes"
hdefs["_MK_BIG_ENDIAN"] = nil
hdefs["HAVE_ALIGNED_ATTRIBUTE"] = "yes"
hdefs["HAVE_BOUNDED_ATTRIBUTE"] = "yes"
hdefs["HAVE_CONST_ATTRIBUTE"] = "yes"
hdefs["HAVE_DEPRECATED_ATTRIBUTE"] = "yes"
hdefs["HAVE_FORMAT_ATTRIBUTE"] = "yes"
hdefs["HAVE_MALLOC_ATTRIBUTE"] = "yes"
hdefs["HAVE_NORETURN_ATTRIBUTE"] = "yes"
hdefs["HAVE_PACKED_ATTRIBUTE"] = "yes"
hdefs["HAVE_PURE_ATTRIBUTE"] = "yes"
hdefs["HAVE_UNUSED_VARIABLE_ATTRIBUTE"] = "yes"
hdefs["HAVE_WARN_UNUSED_RESULT_ATTRIBUTE"] = "yes"
hdefs["AG_USE_ATTRIBUTES"] = "yes"
hdefs["AG_INLINE_BYTESWAP"] = "yes"
hdefs["AG_INLINE_ERROR"] = "yes"
hdefs["AG_INLINE_IO"] = "yes"
hdefs["AG_INLINE_OBJECT"] = "yes"
hdefs["AG_INLINE_STRING"] = "yes"
hdefs["AG_INLINE_TBL"] = "yes"
hdefs["AG_INLINE_THREADS"] = "yes"
hdefs["AG_INLINE_VARIABLE"] = "yes"
hdefs["AG_INLINE_SURFACE"] = "yes"
hdefs["AG_INLINE_WIDGET"] = "yes"
hdefs["_MK_HAVE_SYS_TYPES_H"] = "yes"
hdefs["_MK_HAVE_STDINT_H"] = "yes"
hdefs["HAVE_INT64_T"] = "yes"
hdefs["HAVE___INT64"] = nil
hdefs["HAVE_64BIT"] = "yes"
hdefs["_MK_HAVE_SYS_STAT_H"] = "yes"
hdefs["_MK_HAVE_STDLIB_H"] = "yes"
hdefs["_MK_HAVE_UNISTD_H"] = "yes"
hdefs["_MK_HAVE_LIMITS_H"] = "yes"
hdefs["_MK_HAVE_FLOAT_H"] = "yes"
hdefs["HAVE_MATH"] = "yes"
hdefs["HAVE_MATH_C99"] = "yes"
hdefs["HAVE_FDCLOSE"] = "yes"
hdefs["HAVE_GETPWUID"] = "yes"
hdefs["HAVE_GETPWNAM_R"] = "yes"
hdefs["HAVE_GETENV"] = "yes"
hdefs["HAVE_GETUID"] = "yes"
hdefs["HAVE_STRSEP"] = "yes"
hdefs["HAVE_ASPRINTF"] = "yes"
hdefs["HAVE_SNPRINTF"] = "yes"
hdefs["HAVE_VSNPRINTF"] = "yes"
hdefs["HAVE_VASPRINTF"] = "yes"
hdefs["_MK_HAVE_SIGNAL"] = "yes"
hdefs["_MK_HAVE_STRTOLL"] = "yes"
hdefs["_MK_HAVE_STRTOLD"] = "yes"
hdefs["HAVE_DLFCN_H"] = "yes"
hdefs["HAVE_DLOPEN"] = "yes"
hdefs["HAVE_MACH_O_DYLD_H"] = nil
hdefs["HAVE_DYLD"] = nil
hdefs["HAVE_DYLD"] = nil
hdefs["HAVE_MACH_O_DYLD_H"] = nil
hdefs["HAVE_DYLD_RETURN_ON_ERROR"] = nil
hdefs["HAVE_DL_H"] = nil
hdefs["HAVE_SHL_LOAD"] = nil
hdefs["HAVE_SHL_LOAD"] = nil
hdefs["HAVE_DL_H"] = nil
hdefs["HAVE_GETTIMEOFDAY"] = "yes"
hdefs["HAVE_SELECT"] = "yes"
hdefs["HAVE_GLOB"] = "yes"
hdefs["HAVE_GETOPT"] = "yes"
hdefs["HAVE_EXECVP"] = "yes"
hdefs["HAVE_CLOCK_GETTIME"] = "yes"
hdefs["HAVE_CLOCK_GETTIME"] = "yes"
hdefs["HAVE_CLOCK_WIN32"] = nil
hdefs["HAVE_CLOCK_WIN32"] = nil
hdefs["HAVE_NANOSLEEP"] = "yes"
hdefs["HAVE_KQUEUE"] = "yes"
hdefs["HAVE_TIMERFD"] = nil
hdefs["HAVE_CSIDL"] = nil
hdefs["HAVE_XBOX"] = nil
hdefs["HAVE_MPROTECT"] = "yes"
hdefs["AG_DEBUG"] = nil
hdefs["AG_TYPE_SAFETY"] = nil
hdefs["AG_ANSI_COLOR"] = "yes"
hdefs["AG_ENABLE_DSO"] = "yes"
hdefs["AG_EVENT_LOOP"] = "yes"
hdefs["AG_ENABLE_EXEC"] = "yes"
hdefs["AG_LEGACY"] = "yes"
hdefs["AG_NAMED_ARGS"] = "yes"
hdefs["AG_NAMESPACES"] = "yes"
hdefs["AG_SERIALIZATION"] = "yes"
hdefs["AG_ENABLE_STRING"] = "yes"
hdefs["AG_TIMERS"] = "yes"
hdefs["AG_UNICODE"] = "yes"
hdefs["AG_USER"] = "yes"
hdefs["AG_VERBOSITY"] = "yes"
hdefs["AG_WIDGETS"] = "yes"
hdefs["AG_WM_HINTS"] = "yes"
hdefs["ENABLE_GUI"] = "yes"
hdefs["HAVE_SDL2"] = "yes"
hdefs["HAVE_SDL"] = nil
hdefs["HAVE_OPENGL"] = "yes"
hdefs["HAVE_GLEXT"] = "yes"
hdefs["HAVE_X11"] = "yes"
hdefs["HAVE_XKB"] = "yes"
hdefs["HAVE_XF86MISC"] = nil
hdefs["HAVE_XINERAMA"] = "yes"
hdefs["HAVE_COCOA"] = nil
hdefs["HAVE_COCOA"] = nil
hdefs["HAVE_COCOA"] = nil
hdefs["HAVE_GLX"] = "yes"
hdefs["HAVE_WGL"] = nil
hdefs["HAVE_WGL"] = nil
hdefs["HAVE_WGL"] = nil
hdefs["HAVE_FREETYPE"] = "yes"
hdefs["HAVE_FONTCONFIG"] = "yes"
hdefs["HAVE_JPEG"] = "yes"
hdefs["HAVE_PNG"] = "yes"
hdefs["HAVE_LIBPNG14"] = "yes"
hdefs["ENABLE_MICRO"] = nil
hdefs["HAVE_GETADDRINFO"] = "yes"
hdefs["HAVE_SIOCGIFCONF"] = "yes"
hdefs["HAVE_SETSOCKOPT"] = "yes"
hdefs["HAVE_SO_OOBINLINE"] = "yes"
hdefs["HAVE_SO_REUSEPORT"] = "yes"
hdefs["HAVE_SO_TIMESTAMP"] = "yes"
hdefs["HAVE_SO_NOSIGPIPE"] = nil
hdefs["HAVE_SO_LINGER"] = "yes"
hdefs["HAVE_SO_ACCEPTFILTER"] = nil
hdefs["HAVE_WINSOCK1"] = nil
hdefs["HAVE_WINSOCK2"] = nil
hdefs["AG_NETWORK"] = "yes"
hdefs["HAVE_ZLIB"] = nil
hdefs["HAVE_SYS_UIO_H"] = nil
hdefs["HAVE_SYS_PARAM_H"] = nil
hdefs["AG_WEB"] = nil
hdefs["HAVE_DB4"] = nil
hdefs["HAVE_DB5"] = nil
hdefs["HAVE_MYSQL"] = nil
hdefs["HAVE_PTHREADS"] = "yes"
hdefs["HAVE_PTHREADS_XOPEN"] = "yes"
hdefs["HAVE_PTHREADS_XOPEN"] = "yes"
hdefs["HAVE_PTHREAD_MUTEX_RECURSIVE"] = "yes"
hdefs["HAVE_PTHREAD_MUTEX_RECURSIVE"] = "yes"
hdefs["HAVE_PTHREAD_MUTEX_RECURSIVE_NP"] = nil
hdefs["HAVE_PTHREAD_MUTEX_RECURSIVE_NP"] = nil
hdefs["HAVE_PTHREAD_MUTEX_T_POINTER"] = "yes"
hdefs["HAVE_PTHREAD_COND_T_POINTER"] = "yes"
hdefs["HAVE_PTHREAD_T_POINTER"] = "yes"
hdefs["AG_THREADS"] = "yes"
hdefs["HAVE_ICONV"] = nil
hdefs["HAVE_GETTEXT"] = nil
hdefs["ENABLE_MATH"] = "yes"
hdefs["HAVE_ALTIVEC"] = nil
hdefs["HAVE_ALTIVEC"] = nil
hdefs["HAVE_ALTIVEC"] = nil
hdefs["HAVE_ALTIVEC_H"] = nil
hdefs["HAVE_ALTIVEC_H"] = nil
hdefs["HAVE_ALTIVEC"] = nil
hdefs["HAVE_ALTIVEC_H"] = nil
hdefs["INLINE_ALTIVEC"] = nil
hdefs["HAVE_SSE"] = nil
hdefs["HAVE_SSE2"] = nil
hdefs["HAVE_SSE3"] = nil
hdefs["HAVE_SSE"] = nil
hdefs["HAVE_SSE2"] = nil
hdefs["HAVE_SSE3"] = nil
hdefs["INLINE_SSE"] = nil
hdefs["SINGLE_PRECISION"] = nil
hdefs["DOUBLE_PRECISION"] = "yes"
hdefs["QUAD_PRECISION"] = nil
hdefs["ENABLE_VG"] = "yes"
hdefs["ENABLE_AU"] = "yes"
hdefs["HAVE_SNDFILE"] = "yes"
hdefs["HAVE_PORTAUDIO"] = "yes"
hdefs["ENABLE_MAP"] = "yes"
hdefs["ENABLE_SG"] = "yes"
hdefs["HAVE_GLU"] = "yes"
hdefs["ENABLE_SK"] = "yes"
mdefs["ALTIVEC_CFLAGS"] = ""
mdefs["AVAIL_CONFIGSCRIPTS"] = " agar-core-config agar-config agar-au-config agar-map-config agar-math-config agar-net-config agar-sg-config agar-sk-config agar-vg-config"
mdefs["AVAIL_PCMODULES"] = " agar-core.pc agar.pc agar-au.pc agar-map.pc agar-math.pc agar-net.pc agar-sg.pc agar-sk.pc agar-vg.pc"
mdefs["BINDIR"] = "/usr/local/bin"
mdefs["CC"] = "cc"
mdefs["CC_COMPILE"] = "-c"
mdefs["CFLAGS"] = "-O2 -pipe -D_AGAR_INTERNAL -D_DEFAULT_SOURCE -D_BSD_SOURCE  -I/usr/obj/ports/agar-1.7.0/agar-1.7.0/include"
mdefs["CLOCK_CFLAGS"] = ""
mdefs["CLOCK_LIBS"] = ""
mdefs["COCOA_CFLAGS"] = ""
mdefs["COCOA_LIBS"] = ""
mdefs["CXXFLAGS"] = "-O2 -pipe -D_AGAR_INTERNAL -D_DEFAULT_SOURCE -D_BSD_SOURCE -I/usr/obj/ports/agar-1.7.0/agar-1.7.0/include"
mdefs["DATADIR"] = "/usr/local/share/agar"
mdefs["DB4_CFLAGS"] = ""
mdefs["DB4_LIBS"] = ""
mdefs["DB5_CFLAGS"] = ""
mdefs["DB5_LIBS"] = ""
mdefs["DEVKITPRO"] = ""
mdefs["DSO_CFLAGS"] = ""
mdefs["DSO_LIBS"] = ""
mdefs["ENABLE_GUI_LIBS"] = "-L../gui -lag_gui"
mdefs["ENABLE_MICRO_LIBS"] = ""
mdefs["ENABLE_NLS"] = "no"
mdefs["EXECSUFFIX"] = ""
mdefs["FONTCONFIG_CFLAGS"] = "-I/usr/X11R6/include -I/usr/X11R6/include/freetype2"
mdefs["FONTCONFIG_LIBS"] = "-L/usr/X11R6/lib -lfontconfig -lfreetype"
mdefs["FREETYPE_CFLAGS"] = "-I/usr/X11R6/include/freetype2"
mdefs["FREETYPE_LIBS"] = "-L/usr/X11R6/lib -lfreetype"
mdefs["FREETYPE_PC"] = "freetype2"
mdefs["GETTEXT_CFLAGS"] = ""
mdefs["GETTEXT_LIBS"] = ""
mdefs["GLU_CFLAGS"] = "-I/usr/X11R6/include"
mdefs["GLU_LIBS"] = "-L/usr/X11R6/lib -lGLU"
mdefs["GLX_CFLAGS"] = "-I/usr/X11R6/include -I/usr/X11R6/include"
mdefs["GLX_LIBS"] = " -L/usr/X11R6/lib -lGL -L/usr/X11R6/lib -lX11"
mdefs["HAVE_ALIGNED_ATTRIBUTE"] = "yes"
mdefs["HAVE_ALTIVEC"] = "no"
mdefs["HAVE_ASPRINTF"] = "yes"
mdefs["HAVE_BOUNDED_ATTRIBUTE"] = "yes"
mdefs["HAVE_CC"] = "yes"
mdefs["HAVE_CC65"] = "no"
mdefs["HAVE_CC_CLANG"] = "yes"
mdefs["HAVE_CC_GCC"] = "no"
mdefs["HAVE_CC_WARNINGS"] = "yes"
mdefs["HAVE_CLOCK_GETTIME"] = "yes"
mdefs["HAVE_CLOCK_WIN32"] = "no"
mdefs["HAVE_COCOA"] = "no"
mdefs["HAVE_CONST_ATTRIBUTE"] = "yes"
mdefs["HAVE_CSIDL"] = "no"
mdefs["HAVE_CYGWIN"] = "no"
mdefs["HAVE_DB4"] = "no"
mdefs["HAVE_DB5"] = "no"
mdefs["HAVE_DEPRECATED_ATTRIBUTE"] = "yes"
mdefs["HAVE_DLOPEN"] = "yes"
mdefs["HAVE_EMCC"] = "no"
mdefs["HAVE_FLOAT"] = "yes"
mdefs["HAVE_FONTCONFIG"] = "yes"
mdefs["HAVE_FORMAT_ATTRIBUTE"] = "yes"
mdefs["HAVE_FREETYPE"] = "yes"
mdefs["HAVE_GAMECUBE"] = ""
mdefs["HAVE_GBA"] = ""
mdefs["HAVE_GETTEXT"] = "no"
mdefs["HAVE_GLEXT"] = "yes"
mdefs["HAVE_GLU"] = "yes"
mdefs["HAVE_GLX"] = "yes"
mdefs["HAVE_ICONV"] = "no"
mdefs["HAVE_INT64_T"] = "yes"
mdefs["HAVE_JPEG"] = "yes"
mdefs["HAVE_LD_NO_UNDEFINED"] = ""
mdefs["HAVE_LD_STATIC_LIBGCC"] = ""
mdefs["HAVE_LIBOPENGL32"] = ""
mdefs["HAVE_LONG_DOUBLE"] = "yes"
mdefs["HAVE_MALLOC_ATTRIBUTE"] = "yes"
mdefs["HAVE_MATH"] = "yes"
mdefs["HAVE_MATH_C99"] = "yes"
mdefs["HAVE_MYSQL"] = "no"
mdefs["HAVE_NETWORK"] = "yes"
mdefs["HAVE_NORETURN_ATTRIBUTE"] = "yes"
mdefs["HAVE_OBJC"] = "yes"
mdefs["HAVE_OBJC_WARNINGS"] = "yes"
mdefs["HAVE_OPENGL"] = "yes"
mdefs["HAVE_PACKED_ATTRIBUTE"] = "yes"
mdefs["HAVE_PNG"] = "yes"
mdefs["HAVE_PORTAUDIO"] = "yes"
mdefs["HAVE_PTHREADS"] = "yes"
mdefs["HAVE_PTHREADS_XOPEN"] = "yes"
mdefs["HAVE_PTHREAD_COND_T_POINTER"] = "yes"
mdefs["HAVE_PTHREAD_MUTEX_RECURSIVE"] = "yes"
mdefs["HAVE_PTHREAD_MUTEX_RECURSIVE_NP"] = "no"
mdefs["HAVE_PTHREAD_MUTEX_T_POINTER"] = "yes"
mdefs["HAVE_PTHREAD_T_POINTER"] = "yes"
mdefs["HAVE_PURE_ATTRIBUTE"] = "yes"
mdefs["HAVE_SDL"] = "no"
mdefs["HAVE_SDL2"] = "yes"
mdefs["HAVE_SHL_LOAD"] = "no"
mdefs["HAVE_SNDFILE"] = "yes"
mdefs["HAVE_SSE"] = "no"
mdefs["HAVE_SSE2"] = "no"
mdefs["HAVE_SSE3"] = "no"
mdefs["HAVE_SWITCH"] = ""
mdefs["HAVE_SYS_PARAM_H"] = ""
mdefs["HAVE_SYS_UIO_H"] = ""
mdefs["HAVE_UNUSED_VARIABLE_ATTRIBUTE"] = "yes"
mdefs["HAVE_VASPRINTF"] = "yes"
mdefs["HAVE_WARN_UNUSED_RESULT_ATTRIBUTE"] = "yes"
mdefs["HAVE_WEB"] = "no"
mdefs["HAVE_WGL"] = "no"
mdefs["HAVE_X11"] = "yes"
mdefs["HAVE_XF86MISC"] = "no"
mdefs["HAVE_XINERAMA"] = "yes"
mdefs["HAVE_XKB"] = "yes"
mdefs["HAVE_ZLIB"] = "no"
mdefs["HAVE___INT64"] = "no"
mdefs["ICONV_CFLAGS"] = ""
mdefs["ICONV_LIBS"] = ""
mdefs["INCLDIR"] = "/usr/local/include/agar"
mdefs["JPEG_CFLAGS"] = "-I/usr/local/include"
mdefs["JPEG_LIBS"] = "-L/usr/local/lib -ljpeg"
mdefs["JPEG_PC"] = "libjpeg"
mdefs["LIBDIR"] = "/usr/local/lib"
mdefs["LIBEXECDIR"] = "/usr/local/libexec"
mdefs["LIBTOOLOPTS_SHARED"] = ""
mdefs["LIB_SHARED"] = "Yes"
mdefs["LOCALEDIR"] = "/usr/local/share/agar/locale"
mdefs["MANDIR"] = "/usr/local/man"
mdefs["MATH_C99_CFLAGS"] = ""
mdefs["MATH_C99_LIBS"] = "-lm"
mdefs["MATH_CFLAGS"] = ""
mdefs["MATH_LIBS"] = "-lm"
mdefs["MEMORY_MODEL"] = "MEDIUM"
mdefs["MODULEDIR"] = "/usr/local/lib"
mdefs["MYSQL_CFLAGS"] = ""
mdefs["MYSQL_LIBS"] = ""
mdefs["OPENGL_CFLAGS"] = "-I/usr/X11R6/include"
mdefs["OPENGL_LIBS"] = " -L/usr/X11R6/lib -lGL"
mdefs["OPENGL_PC"] = "gl"
mdefs["PACKAGE"] = "Agar"
mdefs["PATH_SEPARATOR"] = ":"
mdefs["PICFLAGS"] = "-fPIC"
mdefs["PKGCONFIG"] = "/usr/bin/pkg-config"
mdefs["PKGCONFIG_LIBDIR"] = "${PREFIX}/lib/pkgconfig"
mdefs["PNG_CFLAGS"] = "-I/usr/local/include/libpng16"
mdefs["PNG_LIBS"] = "-L/usr/local/lib -lpng"
mdefs["PNG_PC"] = "libpng"
mdefs["PORTAUDIO_CFLAGS"] = "-I/usr/local/include"
mdefs["PORTAUDIO_LIBS"] = "-L/usr/local/lib -lportaudio"
mdefs["PORTAUDIO_PC"] = "portaudio-2.0"
mdefs["PROG_BUNDLE"] = ""
mdefs["PROG_CLI_FLAGS"] = ""
mdefs["PROG_GUI_FLAGS"] = ""
mdefs["PROG_PREFIX"] = ""
mdefs["PROG_SUFFIX"] = ""
mdefs["PROG_TRANSFORM"] = "s,x,x,"
mdefs["PTHREADS_CFLAGS"] = ""
mdefs["PTHREADS_LIBS"] = "-lpthread"
mdefs["PTHREADS_XOPEN_CFLAGS"] = "-U_XOPEN_SOURCE -D_XOPEN_SOURCE=600"
mdefs["PTHREADS_XOPEN_LIBS"] = "-lpthread"
mdefs["RELEASE"] = "Ancient Egypt"
mdefs["SDL2_CFLAGS"] = "-I/usr/local/include -I/usr/local/include/SDL2 -I/usr/X11R6/include -D_REENTRANT -I/usr/X11R6/include"
mdefs["SDL2_LIBS"] = " -L/usr/local/lib -lSDL2 -L/usr/X11R6/lib"
mdefs["SDL2_PC"] = "sdl2"
mdefs["SDL_CFLAGS"] = " -I/usr/X11R6/include -I/usr/X11R6/include"
mdefs["SDL_LIBS"] = ""
mdefs["SDL_PC"] = ""
mdefs["SHL_LOAD_LIBS"] = ""
mdefs["SNDFILE_CFLAGS"] = "-I/usr/local/include -I/usr/local/include/opus"
mdefs["SNDFILE_LIBS"] = "-L/usr/local/lib -lsndfile"
mdefs["SNDFILE_PC"] = "sndfile"
mdefs["SRCS_AU"] = " au_dev_file.c au_dev_pa.c"
mdefs["SRCS_CORE"] = " time_posix.c time_renderer.c time_gettimeofday.c user_posix.c"
mdefs["SRCS_GUI"] = " font_ft.c drv_sdl2_common.c drv_sdl_keysyms.c drv_sdl2fb.c drv_sdl2gl.c drv_sdl2mw.c drv_gl_common.c drv_glx.c"
mdefs["SRCS_NET"] = " net_bsd.c"
mdefs["SSE2_CFLAGS"] = ""
mdefs["SSE3_CFLAGS"] = ""
mdefs["SSE_CFLAGS"] = ""
mdefs["STATEDIR"] = "/usr/local/var"
mdefs["SUBDIR_au"] = "au"
mdefs["SUBDIR_gui"] = "gui"
mdefs["SUBDIR_map"] = "map"
mdefs["SUBDIR_math"] = "math"
mdefs["SUBDIR_micro"] = ""
mdefs["SUBDIR_net"] = "net"
mdefs["SUBDIR_sg"] = "sg"
mdefs["SUBDIR_sk"] = "sk"
mdefs["SUBDIR_vg"] = "vg"
mdefs["SYSCONFDIR"] = "/usr/local/etc"
mdefs["TTFDIR"] = "/usr/local/share/agar/fonts"
mdefs["VERSION"] = "1.7.0"
mdefs["X11_CFLAGS"] = "-I/usr/X11R6/include"
mdefs["X11_LIBS"] = "-L/usr/X11R6/lib -lX11"
mdefs["X11_PC"] = "x11"
mdefs["XINERAMA_CFLAGS"] = "-I/usr/X11R6/include"
mdefs["XINERAMA_LIBS"] = "-L/usr/X11R6/lib -lXinerama"
mdefs["XINERAMA_PC"] = "xinerama"
mdefs["ZLIB_CFLAGS"] = ""
mdefs["ZLIB_LIBS"] = ""
mdefs["_MK_BYTE_ORDER"] = "LE"
mdefs["_MK_HAVE_FLOAT_H"] = "yes"
mdefs["_MK_HAVE_LIMITS_H"] = "yes"
mdefs["_MK_HAVE_STDINT_H"] = "yes"
mdefs["_MK_HAVE_STDLIB_H"] = "yes"
mdefs["_MK_HAVE_SYS_STAT_H"] = "yes"
mdefs["_MK_HAVE_SYS_TYPES_H"] = "yes"
mdefs["_MK_HAVE_UNISTD_H"] = "yes"
